@@ -70,7 +70,7 @@ TODO:publish
 <Pseudo> Y = 0.299*R + 0.587*G + 0.114*B</Pseudo>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL fwiRGBToY_JPEG_8u_P3C1R              ( const Fw8u *pSrcRGB[3], int srcStep,
+FwStatus STDCALL fwiRGBToY_JPEG_8u_P3C1R              ( const Fw8u * const pSrcRGB[3], int srcStep,
                                                                 Fw8u *pDstY     , int dstStep, FwiSize roiSize );
 
 FwStatus STDCALL fwiRGBToY_JPEG_8u_C3C1R              ( const Fw8u *pSrcRGB   , int srcStep,
@@ -90,7 +90,7 @@ FwStatus STDCALL fwiBGRToY_JPEG_8u_C3C1R              ( const Fw8u *pSrcBGR, int
 
 /*#FunctionBlock - RGBToYCbCr_JPEG
 TODO:publish
-#Technologies - REF
+#Technologies - REF, SSE2, MT 
 #Short - Convert RGB to YCbCr (JPEG)
 #Long - <Text>These functions step through an ROI in a source buffer, convert the source data from the RGB color model to the YCbCr color space, and write the converted data to a destination buffer.</Text>
 <Text>The following formulas are used to convert red, green, and blue values to luminance and chrominance values.</Text>
@@ -101,11 +101,11 @@ TODO:publish
 </Pseudo>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL fwiRGBToYCbCr_JPEG_8u_P3R            ( const Fw8u *pSrcRGB[3]  , int srcStep,
+FwStatus STDCALL fwiRGBToYCbCr_JPEG_8u_P3R            ( const Fw8u * const pSrcRGB[3]  , int srcStep,
                                                                 Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize );
 
 FwStatus STDCALL fwiRGBToYCbCr_JPEG_8u_C3P3R          ( const Fw8u *pSrcRGB     , int srcStep,
-                                                                Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize );
+                                                                Fw8u * const pDstYCbCr[3], int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - YCbCrToRGB_JPEG
 TODO:publish
@@ -120,10 +120,10 @@ TODO:publish
 </Pseudo>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL fwiYCbCrToRGB_JPEG_8u_P3R            ( const Fw8u *pSrcYCbCr[3], int srcStep,
+FwStatus STDCALL fwiYCbCrToRGB_JPEG_8u_P3R            ( const Fw8u * const pSrcYCbCr[3], int srcStep,
                                                                 Fw8u *pDstRGB[3]  , int dstStep, FwiSize roiSize );
 
-FwStatus STDCALL fwiYCbCrToRGB_JPEG_8u_P3C3R          ( const Fw8u *pSrcYCbCr[3], int srcStep,
+FwStatus STDCALL fwiYCbCrToRGB_JPEG_8u_P3C3R          ( const Fw8u * const pSrcYCbCr[3], int srcStep,
                                                                 Fw8u *pDstRGB     , int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - RGB5X5ToYCbCr_JPEG
@@ -180,7 +180,7 @@ TODO:publish
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
 FwStatus STDCALL fwiBGRToYCbCr_JPEG_8u_C3P3R          ( const Fw8u *pSrcBGR     , int srcStep,
-                                                                Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize );
+                                                                Fw8u * const pDstYCbCr[3], int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - YCbCrToBGR_JPEG
 TODO:publish
@@ -195,7 +195,7 @@ TODO:publish
 </Pseudo>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL fwiYCbCrToBGR_JPEG_8u_P3C3R          ( const Fw8u *pSrcYCbCr[3], int srcStep,
+FwStatus STDCALL fwiYCbCrToBGR_JPEG_8u_P3C3R          ( const Fw8u * const pSrcYCbCr[3], int srcStep,
                                                                 Fw8u *pDstBGR     , int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - BGR5X5ToYCbCr_JPEG
@@ -258,11 +258,11 @@ TODO:publish
 <Text>The black (K) channel value remains the same during conversion.</Text>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL  fwiCMYKToYCCK_JPEG_8u_P4R           ( const Fw8u *pSrcCMYK[4], int srcStep,
+FwStatus STDCALL  fwiCMYKToYCCK_JPEG_8u_P4R           ( const Fw8u * const pSrcCMYK[4], int srcStep,
                                                                 Fw8u *pDstYCCK[4], int dstStep, FwiSize roiSize );
 
-FwStatus STDCALL  fwiCMYKToYCCK_JPEG_8u_C4P4R         ( const Fw8u *pSrcCMYK   , int srcStep,
-                                                                Fw8u *pDstYCCK[4], int dstStep, FwiSize roiSize );
+FwStatus STDCALL  fwiCMYKToYCCK_JPEG_8u_C4P4R         ( const Fw8u * const pSrcCMYK   , int srcStep,
+                                                                Fw8u * const pDstYCCK[4], int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - YCCKToCMYK_JPEG
 TODO:publish
@@ -284,10 +284,10 @@ TODO:publish
 <Text>The black (K) channel value remains the same during conversion.</Text>
 #ReturnValues - fwStsNoErr, fwStsNullPtrErr, fwStsSizeErr, fwStsStepErr
 */
-FwStatus STDCALL  fwiYCCKToCMYK_JPEG_8u_P4R           ( const Fw8u *pSrcYCCK[4], int srcStep,
+FwStatus STDCALL  fwiYCCKToCMYK_JPEG_8u_P4R           ( const Fw8u * const pSrcYCCK[4], int srcStep,
                                                                 Fw8u *pDstCMYK[4], int dstStep, FwiSize roiSize );
 
-FwStatus STDCALL  fwiYCCKToCMYK_JPEG_8u_P4C4R         ( const Fw8u *pSrcYCCK[4], int srcStep,
+FwStatus STDCALL  fwiYCCKToCMYK_JPEG_8u_P4C4R         ( const Fw8u * const pSrcYCCK[4], int srcStep,
                                                                 Fw8u *pDstCMYK   , int dstStep, FwiSize roiSize );
 
 /*#FunctionBlock - RGBToYCbCr444LS_MCU
@@ -499,7 +499,7 @@ FwStatus STDCALL fwiYCbCr411ToRGBLS_MCU_16s8u_P3C3R       ( const Fw16s *pSrcMCU
 
 /*#FunctionBlock - YCbCr4XXLS_MCUToBGR
 TODO:publish
-#Technologies - REF
+#Technologies - REF, SSE2
 #Short - Convert YCbCr MCU to BGR
 #Long - <Text>These functions step through a minimum coded unit in a source buffer, convert the data from the YCbCr color space to the BGR color model, level-shift the signed values to unsigned values, and write the converted data to a destination buffer.</Text>
 <Text>There are functions to convert minimum coded units with 4:4:4, 4:2:2, and 4:1:1 chroma sampling to 8-bit BGR or to 16-bit BGR with 555 or 565 bit-per-channel encoding.</Text>
