@@ -31,6 +31,7 @@ This software is subject to the Apache v2.0 License.
 #include "fwdev.h"
 #include "fwJPEG.h"
 #include "FwSharedCode_SSE2.h"
+#include "JPEGColorConv.h"
 
 using namespace OPT_LEVEL;
 
@@ -51,7 +52,7 @@ using namespace OPT_LEVEL;
 //RGB image to gray scale using the following formula:
 //	Y = 0.299*R + 0.587*G + 0.114*B
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u *pSrcRGB[3], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u * const pSrcRGB[3], int srcStep, 
 								   Fw8u *pDstY, int dstStep, FwiSize roiSize)
 {
 	if (pSrcRGB == 0 || pDstY == 0) return fwStsNullPtrErr;
@@ -87,32 +88,35 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u *pSrcRGB[3],
 FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_C3C1R)(const Fw8u *pSrcRGB, int srcStep,
 								   Fw8u *pDstY, int dstStep, FwiSize roiSize)
 {
-	if (pSrcRGB == 0 || pDstY == 0) return fwStsNullPtrErr;
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
+    RGBToY_JPEG_8u_C3C1  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fe< RGBToY_JPEG_8u_C3C1 >( data, pSrcRGB, srcStep, pDstY, dstStep, roiSize ); 
+    }
+    else
+    {
+		if (pSrcRGB == 0 || pDstY == 0) return fwStsNullPtrErr;
+		STEPCHECK(srcStep, dstStep);
+		ROISIZECHECK(roiSize);
 
-	//DEV code use shift 8 bit data for coeffcients
-	//0.299*256=76.544, 0.587*256=150.272, 0.114*256=29.184
-	//We use 77, 150, 29 as the modified coeff, and then shift the result
-	//The final answer is equal to nearest neighbor rounding
-	//SEE2 should use 16 bit data shift
-	unsigned short result;
-	int x, y;
-	int srcPos, dstPos;
-
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			//add 0.5 for nearest neighbor rounding
-			result = 77 * pSrcRGB[srcPos] + 150 * pSrcRGB[srcPos+1]
-				+ 29 * pSrcRGB[srcPos+2] + 128;
-			srcPos += 3;
-			pDstY [dstPos++] = (Fw8u)(result>>8);
-		}
-	}
-
-	return fwStsNoErr;
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcRGB,srcStep,pDstY, dstStep);
+                }
+                else
+                    data.REF_CODE(pSrcRGB,srcStep,pDstY,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE(pSrcRGB,srcStep,pDstY,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 }
 
 //-----------------------------------------------------------------------
@@ -161,7 +165,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiBGRToY_JPEG_8u_C3C1R)(const Fw8u *pSrcBGR, in
 //	Cb = -0.16874*R - 0.33126*G + 0.5*B + 128	
 //	Cr = 0.5*R - 0.41869*G - 0.08131*B + 128
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_P3R)(const Fw8u *pSrcRGB[3], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_P3R)(const Fw8u * const pSrcRGB[3], int srcStep, 
 								 Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize)
 {
 	if (pSrcRGB == 0 || pDstYCbCr == 0) return fwStsNullPtrErr;
@@ -205,45 +209,42 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_P3R)(const Fw8u *pSrcRGB[3
 }
 
 FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_C3P3R)(const Fw8u *pSrcRGB, int srcStep, 
-								 Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize)
+								 Fw8u * const pDstYCbCr[3], int dstStep, FwiSize roiSize)
 {
-	if (pSrcRGB == 0 || pDstYCbCr == 0) return fwStsNullPtrErr;
-	if (pDstYCbCr[0] == 0 || pDstYCbCr[1] == 0 || pDstYCbCr[2] == 0 )
-		return fwStsNullPtrErr;
 
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
+    RGBToYCBCR_C3P3  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fec1S3D< RGBToYCBCR_C3P3 >( data, pSrcRGB, srcStep, pDstYCbCr[0], dstStep, pDstYCbCr[1], dstStep, pDstYCbCr[2], dstStep, roiSize ); 
+    }
+    else
+    {
+	    if (pSrcRGB == 0 || pDstYCbCr == 0) return fwStsNullPtrErr;
+	    if (pDstYCbCr[0] == 0 || pDstYCbCr[1] == 0 || pDstYCbCr[2] == 0 )
+		    return fwStsNullPtrErr;
 
-	//DEV code use shift 8 bit data for coeffcients
-	//0.299*256=76.544, 0.587*256=150.272, 0.114*256=29.184
-	//We use 77, 150, 29 as the modified coeff, and then shift the result
-	//-0.16874*256 = -43.19744, -0.33126*256=-84.80256, 0.5*256=128
-	//0.5*256=128, -0.41869*256 = -107.18464, -0.08131*256=-20.81536
-	//The final answer is equal to nearest neighbor rounding
-	//SEE2 should use 16 bit data shift
-	unsigned short result, RVal, GVal, BVal;
-	int x, y;
-	int srcPos, dstPos;
+	    STEPCHECK(srcStep, dstStep);
+	    ROISIZECHECK(roiSize);
 
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			RVal=pSrcRGB[srcPos++]; 
-			GVal=pSrcRGB[srcPos++];
-			BVal=pSrcRGB[srcPos++];
-			
-			//add 0.5 for nearest neighbor rounding
-			result = 77 * RVal + 150 * GVal + 29 * BVal + 128;
-			pDstYCbCr [0][dstPos] = (Fw8u)(result>>8);
-			result = -43 * RVal - 85 * GVal	+ 128 * BVal + 128;
-			pDstYCbCr [1][dstPos] = (Fw8u)((result>>8)+128);
-			result = 128 * RVal - 107 * GVal - 21 * BVal + 128;
-			pDstYCbCr [2][dstPos++] = (Fw8u)((result>>8)+128);
-		}
-	}
 
-	return fwStsNoErr;
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcRGB,srcStep,pDstYCbCr[0],pDstYCbCr[1],pDstYCbCr[2], dstStep);
+                }
+                else
+                    data.REF_CODE(pSrcRGB,srcStep,pDstYCbCr,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE(pSrcRGB,srcStep,pDstYCbCr,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 }
 
 //-----------------------------------------------------------------------
@@ -255,7 +256,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_C3P3R)(const Fw8u *pSrcRGB
 //	G = Y - 0.34414*Cb - 0.71414*Cr + 135.45984
 //	B = Y + 1.772*Cb - 226.816
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3R)(const Fw8u *pSrcYCbCr[3], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3R)(const Fw8u * const pSrcYCbCr[3], int srcStep, 
 									 Fw8u *pDstRGB[3], int dstStep, FwiSize roiSize)
 {
 	if (pSrcYCbCr == 0 || pDstRGB == 0) return fwStsNullPtrErr;
@@ -288,7 +289,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3R)(const Fw8u *pSrcYCbCr
 	return fwStsNoErr;
 }
 
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3C3R)(const Fw8u *pSrcYCbCr[3], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3C3R)(const Fw8u * const pSrcYCbCr[3], int srcStep, 
 									 Fw8u *pDstRGB, int dstStep, FwiSize roiSize)
 {
 	if (pSrcYCbCr == 0 || pDstRGB == 0) return fwStsNullPtrErr;
@@ -298,26 +299,36 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB_JPEG_8u_P3C3R)(const Fw8u *pSrcYCb
 	STEPCHECK(srcStep, dstStep);
 	ROISIZECHECK(roiSize);
 
-	//Reference code only.
-	//SSE2 code need to shift 16 bit 
-	int x, y;
-	int srcPos, dstPos;
+   YCbCrToRGB_JPEG_8u_P3C3R  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fe< YCbCrToRGB_JPEG_8u_P3C3R >( data, pSrcYCbCr[0], srcStep, pSrcYCbCr[1], srcStep, pSrcYCbCr[2], srcStep, pDstRGB, dstStep, roiSize ); 
+    }
+    else
+    {
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcYCbCr[0],pSrcYCbCr[1],pSrcYCbCr[2],srcStep,pDstRGB,dstStep);
+                }
+                else if(roiSize.width ==16 && roiSize.height == 16)
+                {
+                    data.SSE_16(pSrcYCbCr[0],pSrcYCbCr[1],pSrcYCbCr[2],srcStep,pDstRGB,dstStep);
+                }
+                else
+                    data.REF_CODE_OPT(pSrcYCbCr,srcStep,pDstRGB,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE_OPT(pSrcYCbCr,srcStep,pDstRGB,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			//add 0.5 for nearest neighbor rounding
-			pDstRGB[dstPos++] = FW_REF::Limits<U8>::Sat(pSrcYCbCr[0][srcPos] + 
-				1.402*pSrcYCbCr[2][srcPos] - 178.956);
-			pDstRGB[dstPos++] = FW_REF::Limits<U8>::Sat(pSrcYCbCr[0][srcPos] - 
-				0.34414*pSrcYCbCr[1][srcPos] - 0.71414*pSrcYCbCr[2][srcPos]+ 135.95984);
-			pDstRGB[dstPos++] = FW_REF::Limits<U8>::Sat(pSrcYCbCr[0][srcPos] + 
-				1.772*pSrcYCbCr[1][srcPos++] - 226.316);
-		}
-	}
-
-	return fwStsNoErr;
 }
 
 //-----------------------------------------------------------------------
@@ -524,7 +535,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToRGB555_JPEG_8u16u_P3C3R)(const Fw8u *p
 //	Cr = 0.5*R - 0.41869*G - 0.08131*B + 128
 //-----------------------------------------------------------------------
 FwStatus PREFIX_OPT(OPT_PREFIX, fwiBGRToYCbCr_JPEG_8u_C3P3R)(const Fw8u *pSrcBGR, int srcStep, 
-								 Fw8u *pDstYCbCr[3], int dstStep, FwiSize roiSize)
+								 Fw8u * const pDstYCbCr[3], int dstStep, FwiSize roiSize)
 {
 	if (pSrcBGR == 0 || pDstYCbCr == 0) return fwStsNullPtrErr;
 	if (pDstYCbCr[0] == 0 || pDstYCbCr[1] == 0 || pDstYCbCr[2] == 0 )
@@ -574,7 +585,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiBGRToYCbCr_JPEG_8u_C3P3R)(const Fw8u *pSrcBGR
 //	G = Y - 0.34414*Cb - 0.71414*Cr + 135.45984
 //	B = Y + 1.772*Cb - 226.816
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToBGR_JPEG_8u_P3C3R)(const Fw8u *pSrcYCbCr[3], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToBGR_JPEG_8u_P3C3R)(const Fw8u * const pSrcYCbCr[3], int srcStep, 
 									 Fw8u *pDstBGR, int dstStep, FwiSize roiSize)
 {
 	if (pSrcYCbCr == 0 || pDstBGR == 0) return fwStsNullPtrErr;
@@ -814,7 +825,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCbCrToBGR555_JPEG_8u16u_P3C3R)(const Fw8u *p
 //	Cr = 0.5*R - 0.41869*G - 0.08131*B + 128
 //The values of K channel are written without modification.
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_P4R)(const Fw8u *pSrcCMYK[4], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_P4R)(const Fw8u *const pSrcCMYK[4], int srcStep, 
 									 Fw8u *pDstYCCK[4], int dstStep, FwiSize roiSize)
 {
 	if (pSrcCMYK == 0 || pDstYCCK == 0) return fwStsNullPtrErr;
@@ -861,50 +872,45 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_P4R)(const Fw8u *pSrcCMYK[
 	return fwStsNoErr;
 }
 
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u *pSrcCMYK, int srcStep, 
-									 Fw8u *pDstYCCK[4], int dstStep, FwiSize roiSize)
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u * const pSrcCMYK, int srcStep, 
+									 Fw8u *const pDstYCCK[4], int dstStep, FwiSize roiSize)
 {
-	if (pSrcCMYK == 0 || pDstYCCK == 0) return fwStsNullPtrErr;
-	if (pDstYCCK[0] == 0 || pDstYCCK[1] == 0 || pDstYCCK[2] == 0 ||
-		pDstYCCK[3] == 0)
-		return fwStsNullPtrErr;
 
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
+    CMYKToYCCK_JPEG_8u_C4P4R  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fec1S4D< CMYKToYCCK_JPEG_8u_C4P4R >( data, pSrcCMYK, srcStep, pDstYCCK[0], dstStep, pDstYCCK[1], dstStep, pDstYCCK[2], dstStep, pDstYCCK[3], dstStep,roiSize ); 
+    }
+    else
+    {
+	  	if (pSrcCMYK == 0 || pDstYCCK == 0) return fwStsNullPtrErr;
+		if (pDstYCCK[0] == 0 || pDstYCCK[1] == 0 || pDstYCCK[2] == 0 ||
+			pDstYCCK[3] == 0)
+			return fwStsNullPtrErr;
 
-	//DEV code use shift 8 bit data for coeffcients
-	//0.299*256=76.544, 0.587*256=150.272, 0.114*256=29.184
-	//We use 77, 150, 29 as the modified coeff, and then shift the result
-	//-0.16874*256 = -43.19744, -0.33126*256=-84.80256, 0.5*256=128
-	//0.5*256=128, -0.41869*256 = -107.18464, -0.08131*256=-20.81536
-	//The final answer is equal to nearest neighbor rounding
-	//SEE2 should use 16 bit data shift
-	//int result;
-	unsigned short result;
-	unsigned char RVal, GVal, BVal;
-	int x, y;
-	int srcPos, dstPos;
+		STEPCHECK(srcStep, dstStep);
+		ROISIZECHECK(roiSize);
 
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			RVal = ~(pSrcCMYK[srcPos++]);//R=255-C
-			GVal = ~(pSrcCMYK[srcPos++]);//G=255-M
-			BVal = ~(pSrcCMYK[srcPos++]);//B=255-Y
 
-			//add 0.5 for nearest neighbor rounding
-			result = 77 * RVal + 150 * GVal + 29 * BVal + 128;
-			pDstYCCK [0][dstPos] = (Fw8u)(result>>8);
-			result = -43 * RVal - 85 * GVal + 128 * BVal + 128;
-			pDstYCCK [1][dstPos] = (Fw8u)((result>>8)+128);
-			result = 128 * RVal - 107 * GVal - 21 * BVal + 128;
-			pDstYCCK [2][dstPos] = (Fw8u)((result>>8)+128);
-			pDstYCCK [3][dstPos++] = pSrcCMYK[srcPos++];
-		}
-	}
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcCMYK,srcStep,pDstYCCK[0],pDstYCCK[1],pDstYCCK[2],pDstYCCK[3], dstStep);
+                }
+                else
+                    data.REF_CODE(pSrcCMYK,srcStep,pDstYCCK,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE(pSrcCMYK,srcStep,pDstYCCK,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 
-	return fwStsNoErr;
 }
 
 //-----------------------------------------------------------------------
@@ -919,7 +925,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u *pSrcCMY
 //	Y = 255  B
 //The values of K channel are written without modification.
 //-----------------------------------------------------------------------
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCCKToCMYK_JPEG_8u_P4R)(const Fw8u *pSrcYCCK[4], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCCKToCMYK_JPEG_8u_P4R)(const Fw8u * const pSrcYCCK[4], int srcStep, 
 									 Fw8u *pDstCMYK[4], int dstStep, FwiSize roiSize)
 {
 	if (pSrcYCCK == 0 || pDstCMYK == 0) return fwStsNullPtrErr;
@@ -958,45 +964,44 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCCKToCMYK_JPEG_8u_P4R)(const Fw8u *pSrcYCCK[
 	return fwStsNoErr;
 }
 
-FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCCKToCMYK_JPEG_8u_P4C4R)(const Fw8u *pSrcYCCK[4], int srcStep, 
+FwStatus PREFIX_OPT(OPT_PREFIX, fwiYCCKToCMYK_JPEG_8u_P4C4R)(const Fw8u * const pSrcYCCK[4], int srcStep, 
 									 Fw8u *pDstCMYK, int dstStep, FwiSize roiSize)
 {
-	if (pSrcYCCK == 0 || pDstCMYK == 0) return fwStsNullPtrErr;
-	if (pSrcYCCK[0] == 0 || pSrcYCCK[1] == 0 || pSrcYCCK[2] == 0 || 
-		pSrcYCCK[3] == 0)
-		return fwStsNullPtrErr;
 
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
 
-	//Reference code only.
-	//SSE2 code need to shift 16 bit 
-	int x, y;
-	unsigned char RVal, GVal, BVal;
-	int srcPos, dstPos;
+	YCCKToCMYK_JPEG_8u_P4C4R data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fec4S1D< YCCKToCMYK_JPEG_8u_P4C4R >( data, pSrcYCCK[0], srcStep,pSrcYCCK[1], srcStep,pSrcYCCK[2], srcStep,pSrcYCCK[3], srcStep, pDstCMYK, dstStep, roiSize ); 
+    }
+    else
+    {
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcYCCK[0],pSrcYCCK[1],pSrcYCCK[2],pSrcYCCK[3],srcStep,pDstCMYK,dstStep);
+                }
+                else if(roiSize.width ==16 && roiSize.height == 16)
+                {
+                    data.SSE_16(pSrcYCCK[0],pSrcYCCK[1],pSrcYCCK[2],pSrcYCCK[3],srcStep,pDstCMYK,dstStep);
+                }
+                else
+                    data.REF_CODE_OPT(pSrcYCCK,srcStep,pDstCMYK,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE_OPT(pSrcYCCK,srcStep,pDstCMYK,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			//add 0.5 for nearest neighbor rounding
-			RVal = FW_REF::Limits<U8>::Sat(pSrcYCCK[0][srcPos] + 
-				1.402*pSrcYCCK[2][srcPos] - 178.956);
-			GVal = FW_REF::Limits<U8>::Sat(pSrcYCCK[0][srcPos] - 
-				0.34414*pSrcYCCK[1][srcPos] - 0.71414*pSrcYCCK[2][srcPos]+ 135.95984);
-			BVal = FW_REF::Limits<U8>::Sat(pSrcYCCK[0][srcPos] + 
-				1.772*pSrcYCCK[1][srcPos] - 226.316);
-			pDstCMYK[dstPos++] = ~RVal; //C=255-R
-			pDstCMYK[dstPos++] = ~GVal; //M=255-G
-			pDstCMYK[dstPos++] = ~BVal; //Y=255-B
-			pDstCMYK[dstPos++] = pSrcYCCK[3][srcPos++];
-		}
-	}
-
-	return fwStsNoErr;
 }
 
 #endif //BUILD_NUM_AT_LEAST
 
 // Please do NOT remove the above line for CPP files that need to be multipass compiled
-// OREFR 
+// OREFR OSSE2
